==> haskell-stringsearch-0.3.6.6-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringsearch
version:              0.3.6.6
visibility:           public
id:                   stringsearch-0.3.6.6-8k8ZD3cRZ0sIqI7ruc4mNx
key:                  stringsearch-0.3.6.6-8k8ZD3cRZ0sIqI7ruc4mNx
license:              BSD-3-Clause
copyright:
    (c) 2007-2011
    Daniel Fischer, Chris Kuklewicz, Justin Bailey

maintainer:           daniel.is.fischer@googlemail.com
author:               Daniel Fischer, Chris Kuklewicz, Justin Bailey
homepage:             https://bitbucket.org/dafis/stringsearch
synopsis:             Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.

category:             Text, Search
abi:                  3d84b1a7ed9d5ea877f5769f2476a8ec
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Search Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KMP
    Data.ByteString.Lazy.Search.KarpRabin Data.ByteString.Search
    Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
    Data.ByteString.Search.KMP Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution

hidden-modules:
    Data.ByteString.Search.Internal.BoyerMoore
    Data.ByteString.Search.Internal.KnuthMorrisPratt
    Data.ByteString.Search.Internal.Utils
    Data.ByteString.Lazy.Search.Internal.BoyerMoore

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stringsearch-0.3.6.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringsearch
hs-libraries:         HSstringsearch-0.3.6.6-8k8ZD3cRZ0sIqI7ruc4mNx
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1

haddock-interfaces:
    /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock

haddock-html:         /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringsearch-0.3.6.6-26-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stringsearch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stringsearch
version:              0.3.6.6
visibility:           public
id:                   stringsearch-0.3.6.6-LrUcMTg4K1D2VjVEBj7ZcS
key:                  stringsearch-0.3.6.6-LrUcMTg4K1D2VjVEBj7ZcS
license:              BSD-3-Clause
copyright:
    (c) 2007-2011
    Daniel Fischer, Chris Kuklewicz, Justin Bailey

maintainer:           daniel.is.fischer@googlemail.com
author:               Daniel Fischer, Chris Kuklewicz, Justin Bailey
homepage:             https://bitbucket.org/dafis/stringsearch
synopsis:             Fast searching, splitting and replacing of ByteStrings
description:
    This package provides several functions to quickly
    search for substrings in strict or lazy ByteStrings.
    It also provides functions for breaking or splitting
    on substrings and replacing all occurrences of a
    substring (the first in case of overlaps) with another.
    GHC before 6.10 are no longer supported, other compilers
    only if they support BangPatterns. If you need it to
    work with other compilers, send a feature request.

category:             Text, Search
abi:                  5df620e2c5b97108431d291809715a16
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Search Data.ByteString.Lazy.Search.DFA
    Data.ByteString.Lazy.Search.KMP
    Data.ByteString.Lazy.Search.KarpRabin Data.ByteString.Search
    Data.ByteString.Search.BoyerMoore Data.ByteString.Search.DFA
    Data.ByteString.Search.KMP Data.ByteString.Search.KarpRabin
    Data.ByteString.Search.KnuthMorrisPratt
    Data.ByteString.Search.Substitution

hidden-modules:
    Data.ByteString.Search.Internal.BoyerMoore
    Data.ByteString.Search.Internal.KnuthMorrisPratt
    Data.ByteString.Search.Internal.Utils
    Data.ByteString.Lazy.Search.Internal.BoyerMoore

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stringsearch-0.3.6.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stringsearch-0.3.6.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stringsearch-0.3.6.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stringsearch
hs-libraries:         HSstringsearch-0.3.6.6-LrUcMTg4K1D2VjVEBj7ZcS
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7

haddock-interfaces:
    /usr/share/doc/haskell-stringsearch/html/stringsearch.haddock

haddock-html:         /usr/share/doc/haskell-stringsearch/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
